@@ -6,6 +6,7 @@ import re
 from ingredient_slicer import IngredientSlicer
 
 # -------------------------------------------------------------------------------
+
 # -------------------------------------------------------------------------------
 # ---- Simple standard form ingredients tests ----
 # Standard form: "1 cup of sugar" (quantity, unit, ingredient)
@@ -21,14 +22,14 @@ def test_standard_formatted_ingredients():
     assert parsed['is_required'] == True
 
     parse2 = IngredientSlicer("1/2 cup of sugar")
-    parse2.parse()
+    # parse2.parse()
     parsed = parse2.to_json()
     assert parsed['quantity'] == "0.5"
     assert parsed['unit'] == 'cup'
     assert parsed['is_required'] == True
 
     parse3 = IngredientSlicer("1 1/2 cups of sugar")
-    parse3.parse()
+    # parse3.parse()
     parsed = parse3.to_json()
     assert parsed['quantity'] == "1.5"
     assert parsed['unit'] == 'cups'
@@ -199,6 +200,7 @@ def test_fraction_as_quantity_2():
 # -------------------------------------------------------------------------------
 def test_single_unicode_fractions_1():
     parse = IngredientSlicer("½cup of sugar")
+    # IngredientSlicer("½cup of sugar", debug=True)
     # parse.parse()
     parsed = parse.to_json()
 
